%global py3_build_dir %{_builddir}/%{name}-%{version}-%{release}-python3

Name:           pywbem 
Version:        0.9.0
Release:        1%{?dist}
Summary:        Python2 WBEM Client and Provider Interface
Group:          Development/Libraries
License:        LGPLv2
URL:            https://github.com/pywbem/pywbem
Source0:        https://github.com/pywbem/pywbem/archive/v%{version}.tar.gz
BuildRequires:  python-pip PyYAML python-ply
BuildRequires:  python3-pip python3-PyYAML python3-ply
BuildArch:      noarch

%description
A Python library for making CIM (Common Information Model) operations over HTTP 
using the WBEM CIM-XML protocol. It is based on the idea that a good WBEM 
client should be easy to use and not necessarily require a large amount of 
programming knowledge. It is suitable for a large range of tasks from simply 
poking around to writing web and GUI applications. 

WBEM, or Web Based Enterprise Management is a manageability protocol, like 
SNMP, standardised by the Distributed Management Task Force (DMTF) available 
at http://www.dmtf.org/standards/wbem.

It also provides a Python provider interface, and is the fastest and 
easiest way to write providers on the planet.

%package -n python3-pywbem
Group:          Development/Libraries
Summary:        Python3 WBEM Client and Provider Interface 
BuildArch:      noarch

%description -n python3-pywbem
A WBEM client allows issuing operations to a WBEM server, using the CIM
operations over HTTP (CIM-XML) protocol defined in the DMTF standards DSP0200
and DSP0201. The CIM/WBEM infrastructure is used for a wide variety of systems
management tasks supported by systems running WBEM servers. See WBEM Standards
for more information about WBEM.

%package twisted
Group:          Development/Libraries
Summary:        WBEM client bindings for Twisted Python
Requires:       python-twisted-core
Requires:       python-twisted-web
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description twisted
This module contains factory classes that produce WBEM5Client instances
that perform WBEM requests over HTTP using the
twisted.protocols.http.HTTPClient base class.

%prep
%setup -q -n %{name}-%{version}

%build
cp -a . %{py3_build_dir}
CFLAGS="%{optflags}" %{__python2} setup.py build
pushd %{py3_build_dir}
CFLAGS="%{optflags}" %{__python3} setup.py build
popd

%install
rm -rf %{buildroot}
env PYTHONPATH=%{buildroot}/%{python2_sitelib} %{__python2} setup.py install -O1 --skip-build --root %{buildroot}
rm -rf %{buildroot}/usr/bin/
install -m644 attic/twisted_client.py  %{buildroot}/%{python2_sitelib}/pywbem/twisted_client.py

pushd %{py3_build_dir}
env PYTHONPATH=%{buildroot}/%{python3_sitelib} %{__python3} setup.py install -O1 --skip-build --root %{buildroot}
rm -rf %{buildroot}/usr/bin/*.bat
popd

%clean 
rm -rf %{buildroot}

%files
%{python2_sitelib}/*.egg-info
%{python2_sitelib}/pywbem/*.py*
%{python2_sitelib}/pywbem/LICENSE.txt

%files -n python3-pywbem
%{python3_sitelib}/*.egg-info
%{python3_sitelib}/pywbem/*.py*
%{python3_sitelib}/pywbem/LICENSE.txt
%{python3_sitelib}/pywbem/__pycache__/*
%{_bindir}/mof_compiler
%{_bindir}/wbemcli
%doc README.md

%files twisted
%{python_sitelib}/pywbem/twisted_client.py*

%changelog
* Wed Sep 14 2016 Gris Ge <fge@redhat.com> - 0.9.0-1
- Upgrade to 0.9.0 and add python3 pacakge -- python3-pywbem.

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-30.20131121svn626
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-29.20131121svn626
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-28.20131121svn626
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jun 30 2014 Toshio Kuratomi <toshio@fedoraproject.org> - 0.7.0-27.svn
- Replace python-setuptools-devel BR with python-setuptools

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-26.20131121svn626
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Feb 24 2014 Michal Minar <miminar@redhat.com> 0.7.0-25.20131121svn656
- Fixed local authentication under root.

* Thu Jan 23 2014 Michal Minar <miminar@redhat.com> 0.7.0-24.20131121svn656
- Added support for non-ascii strings.

* Fri Jan 03 2014 Michal Minar <miminar@redhat.com> 0.7.0-23.20131121svn656
- Skip hostname check when no verification is desired.

* Fri Dec 27 2013 Michal Minar <miminar@redhat.com> 0.7.0-22.20131121svn656
- Work around M2Crypto's inability to handle unicode strings.

* Wed Dec 18 2013 Michal Minar <miminar@redhat.com> 0.7.0-21.20131121svn656
- Adjusted default certificates paths searched for cert validation.

* Tue Dec 17 2013 Michal Minar <miminar@redhat.com> 0.7.0-20.20131121svn656
- Tweaked the ssl_verify_host patch.

* Mon Dec 16 2013 Michal Minar <miminar@redhat.com> 0.7.0-18.20131121svn656
- Fixes TOCTOU vulnerability in certificate validation.
- Resolves: rhbz#1026891

* Thu Nov 21 2013 Jan Safranek <jsafrane@redhat.com> 0.7.0-17.20131121svn626
- Added '-d' option to /usr/bin/mofcomp to just check mof files and their
  includes.

* Tue Aug 27 2013 Jan Safranek <jsafrane@redhat.com> 0.7.0-16.20130827svn625
- Fixed parsing of IPv6 addresses.

* Fri Aug 09 2013 Michal Minar <miminar@redhat.com> 0.7.0-15.20130723svn623
- Fixed certificate verification issue.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-14.20130723svn623
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 24 2013  <jsafrane@redhat.com> 0.7.0-13.20130702svn623
- Added subpackage with Twisted module to reduce dependencies of the main package.

* Tue Jul 23 2013  <jsafrane@redhat.com> 0.7.0-12.20130702svn623
- Fixed checking of CIMVERSION in CIM-XML.

* Tue Jul  2 2013 Jan Safranek <jsafrane@redhat.com> 0.7.0-11.20130702svn622
- New upstream version.
- Method parameters are now case-insensitive.

* Fri May 24 2013 Tomas Bzatek <tbzatek@redhat.com> 0.7.0-10.20130411svn619
- Fix module imports in /usr/bin/mofcomp

* Thu Apr 11 2013 Jan Safranek <jsafrane@redhat.com> 0.7.0-9.20130411svn619
- New upstream version.
- Removed debug 'print' statements.

* Mon Jan 28 2013 Michal Minar <miminar@redhat.com> 0.7.0-8.20130128svn613
- New upstream version.
- Added post-release snapshot version info.
- Removed obsoleted BuildRoot,

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 0.7.0-4
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri Jan 01 2010 David Nalley <david@gnsa.us> 0.7.0-3
- refined requires for epel compat
* Sun Jun 28 2009 David Nalley <david@gnsa.us> 0.7.0-2
- Added some verbiage regarding what WBEM is and expanding WBEM and CIM acronyms
- Added python-twisted as a dependency
* Thu Jun 25 2009 David Nalley <david@gnsa.us> 0.7.0-1
- Initial packaging

